from django.db import models
from tickets.models import Ticket
from SharixAdmin.models import SharixUser

class Company(models.Model):
    legal_name = models.CharField(max_length=150, help_text="настоящее имя юридического лица")
    repr_id = models.ForeignKey(SharixUser, on_delete=models.DO_NOTHING, help_text="уникальный идентификатор представителя компании. Это обязательно пользователь-провайдер определенного типа. То есть нельзя назначить ответственного, который не может быть ответственным.")
    inn = models.CharField(max_length=10, unique=True, help_text="ИНН компании")
    kpp = models.CharField(max_length=9,  help_text="КПП компании")
    ogrn = models.CharField(max_length=13, help_text="ОГРН компании")
    bank_name = models.CharField(max_length=150, help_text="Название банка с расчетным счетом")
    bik = models.CharField(max_length=9, help_text="БИК компании")
    ks = models.CharField(max_length=50, help_text="Корреспондентский счёт (счёт, открываемый банковской организацией в подразделении самого банка)")
    rs = models.CharField(max_length=50, help_text="Расчетный счет")
    address = models.CharField(max_length=150, help_text="Юридический адрес")
    requirements = models.CharField(max_length=150, help_text="код необходимого (самый строгий) для того, чтобы ресурс мог стать активным. Оно вставляется автоматом, в соответствии с профилем метасервиса. Далее, если кому-то из партнеров или пользователей надо строже - применяется более строгий вариант на данную связь.")
    status = models.CharField(max_length=150, help_text="статус обработки заявки в системе заявок")
    ticket_status = models.ForeignKey(Ticket, on_delete=models.DO_NOTHING, help_text="id заявки, по которой происходит проверка статуса relationship. State меняется только в результате изменений в заявке.")
    id_metaservice = models.BigIntegerField(null=True, help_text="уникальный идентификатор мета-сервиса, необходимый для синхронизации данных. Один и тот же провайдер может быть для нескольких мета-сервисов, соответственно если происходят изменения в одном, то либо форсируется изменение во всех (если возможно), либо снимается is_global. Соответственно при изменении is_global в true должно происходить согласование с остальными копиями в других сервисах. Нужен в том числе для того, чтобы выяснять, в каких еще сервисах есть этот провайдер.")
    is_global = models.BooleanField(default=False, help_text="доступно ли для хранения в глобальном сервисе/нужна синхронизация данных")
    is_visible = models.BooleanField(default=False, help_text="доступно ли для планирования в цепочке с другими услугами в глобальном сервисе")

    
    class Meta:
        db_table = "company"
        verbose_name = "Компания"
        verbose_name_plural = "Компании"