from django.db import models
from SharixAdmin.models import SharixUser
from tickets.models import Ticket

class Permissions(models.Model):
    """
    Разрешения - (проверки/экзамены). 
    По смыслу это что-то вроде “документа на право что-то делать” - на данном этапе это ограничено метасервисом/платформой, 
    при этом он может быть полностью цифровым (выданным платформой/сервисом).
    """
    
    check_date = models.DateTimeField(null=True, help_text="timestamp проверки")
    id_permissions = models.BigIntegerField(help_text="уникальный идентификатор определяющий наличие разрешения из множества в словаре - выданных пользователю/клиенту/аккаунту")
    check_level = models.CharField(max_length=10, help_text="(check-level из классификатора платформы) - информация об уровне проверки. Проверка может быть проведена как платформой, так и мета-сервисом, так и партнером мета-сервиса, а может быть и никем (просто загружен). Указывается, так как достоверность проверки разная. Экзамен, проверенный только на низком уровне, не принимается во внимание как имеющийся до прохождения более высокоуровневой проверки.")
    checked_by = models.ForeignKey(SharixUser, related_name="checked_by_perm", on_delete=models.DO_NOTHING, null=True, help_text="userid проверившего")
    user_id = models.ForeignKey(SharixUser, related_name="user_id_perm", on_delete=models.DO_NOTHING, null=True, help_text="уникальный идентификатор пользователя/клиента/аккаунта, которым была пройдена проверка и получено разрешение")
    status = models.CharField(max_length=150, help_text="статус обработки заявки в системе заявок")
    ticket_status = models.ForeignKey(Ticket, on_delete=models.DO_NOTHING, null=True, help_text="id заявки, по которой происходит проверка статуса relationship. State меняется только в результате изменений в заявке.")
    id_metaservice = models.BigIntegerField(help_text=" уникальный идентификатор мета-сервиса, необходимый для синхронизации данных.")
    is_global = models.BooleanField(default=False, help_text="доступна ли информация для хранения в глобальном сервисе/нужна синхронизация")
    is_visible = models.BooleanField(default=False, help_text="доступна ли информация о наличии разрешения для планирования в цепочке с другими услугами в глобальном сервисе")

    class Meta:
        db_table = "permissions"
        verbose_name = "Разрешение"
        verbose_name_plural = "Разрешения"