from django.db import models
from SharixAdmin.models import SharixUser
from tickets.models import Ticket

class Relationship(models.Model):
    """
    Relationship - описание связей 
    (желательных - как имеющиеся договорные отношения, 
    и нежелательных - как пожелание любой из сторон)
    """
    user_id_who = models.ForeignKey(SharixUser, related_name="user_id_who", on_delete=models.DO_NOTHING, help_text="уникальный идентификатор инициатора договорных отношений")
    user_id_whom = models.ForeignKey(SharixUser,  related_name="user_id_whom", on_delete=models.DO_NOTHING, help_text=" уникальный идентификатор того с кем связываются")
    neg_type = models.IntegerField(help_text="тип договорных отношений по его уникальному идентификатору")
    id_metaservice = models.BigIntegerField(null=True, help_text="уникальный идентификатор мета-сервиса, необходимый для синхронизации данных. Один и тот же провайдер может быть для нескольких мета-сервисов, соответственно если происходят изменения в одном, то либо форсируется изменение во всех (если возможно), либо снимается is_global. Соответственно при изменении is_global в true должно происходить согласование с остальными копиями в других сервисах. Нужен в том числе для того, чтобы выяснять, в каких еще сервисах есть этот провайдер.")
    requirements = models.CharField(max_length=150, help_text="код необходимого (самый строгий) для того, чтобы ресурс мог стать активным. Оно вставляется автоматом, в соответствии с профилем метасервиса. Далее, если кому-то из партнеров или пользователей надо строже - применяется более строгий вариант на данную связь.")
    status = models.CharField(max_length=150, help_text="(статус обработки заявки в системе заявок)")
    ticket_status = models.ForeignKey(Ticket, on_delete=models.DO_NOTHING, help_text="id заявки, по которой происходит проверка статуса relationship. State меняется только в результате изменений в заявке.")
    is_global = models.BooleanField(default=False, help_text="установленный тип договорных отношений между клиентами/пользователями/аккаунтами доступен для хранения в глобальном сервисе/нужна синхронизация")
    is_visible = models.BooleanField(default=False, help_text="установленный тип договорных отношений между клиентами/пользователями/аккаунтами, доступен для планирования в цепочке с другими услугами в глобальном сервисе")


    class Meta:
        db_table = "relationship"
        verbose_name = "Связь (Договорное отношение)"
        verbose_name_plural = "Связи (Договорные отношения)"